Documentation
¶
Overview ¶
This parser package provides lexer and parser of lambda calculus.
Note that parser.go is auto-generated from parser.y, using goyacc. (So there is some auto-generated constants even in godoc of this package.)
If you want to re-generate parser.go, run
$ go generate
or use goyacc directly (please look at generate.go).
If you want to know more, especially about <prefix>Lexer and <prefix>Parser, read the godoc of goyacc.
References:
golang.org/x/tools/cmd/goyacc/testdata/expr/expr.y
github.com/golang/go/src/go/parser/parser_test.go
TODO(nekketsuuu): Add a location info into yyLex, and print a error with the location.
TODO(nekketsuuu): Use buffer instead of naive []bytes.
Index ¶
Constants ¶
const DOT = 57349
const IDENT = 57350
const LAMBDA = 57348
const LPAR = 57346
const RPAR = 57347
Variables ¶
This section is empty.
Functions ¶
func IsBasicDigit ¶
IsBasicDigit reports whether the rune is a letter of [0-9].
func IsBasicLatinAlphabet ¶
IsBasicLatinAlphabet reports whether the rune is a letter of [A-Za-z].
Types ¶
This section is empty.